==> WPyrogram-2.0.150-py3-none-any.whl: pyrogram/raw/base/payments/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .payment_form import PaymentForm
from .validated_requested_info import ValidatedRequestedInfo
from .payment_result import PaymentResult
from .payment_receipt import PaymentReceipt
from .saved_info import SavedInfo
from .bank_card_data import BankCardData
from .exported_invoice import ExportedInvoice
from .checked_gift_code import CheckedGiftCode
from .giveaway_info import GiveawayInfo
from .stars_status import StarsStatus
from .stars_revenue_stats import StarsRevenueStats
from .stars_revenue_withdrawal_url import StarsRevenueWithdrawalUrl
from .stars_revenue_ads_account_url import StarsRevenueAdsAccountUrl
from .star_gifts import StarGifts
from .user_star_gifts import UserStarGifts

==> WPyrogram-2.0.152-py3-none-any.whl: pyrogram/raw/base/payments/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .payment_form import PaymentForm
from .validated_requested_info import ValidatedRequestedInfo
from .payment_result import PaymentResult
from .payment_receipt import PaymentReceipt
from .saved_info import SavedInfo
from .bank_card_data import BankCardData
from .exported_invoice import ExportedInvoice
from .checked_gift_code import CheckedGiftCode
from .giveaway_info import GiveawayInfo
from .stars_status import StarsStatus
from .stars_revenue_stats import StarsRevenueStats
from .stars_revenue_withdrawal_url import StarsRevenueWithdrawalUrl
from .stars_revenue_ads_account_url import StarsRevenueAdsAccountUrl
from .star_gifts import StarGifts
from .user_star_gifts import UserStarGifts
from .connected_star_ref_bots import ConnectedStarRefBots
from .suggested_star_ref_bots import SuggestedStarRefBots
from .star_gift_upgrade_preview import StarGiftUpgradePreview
from .unique_star_gift import UniqueStarGift
